# remirepo/fedora spec file for php-roundcube-rtf-html-php
#
# Copyright (c) 2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%bcond_without tests

# Github
%global gh_commit    7b488113e6fe2fccd84643e5121070fe7f335cb2
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     roundcube
%global gh_project   rtf-html-php
# Packagist
%global pk_vendor    %{gh_owner}
%global pk_name      %{gh_project}
# Namespace (vendor is a fake level)
%global ns_vendor    Roundcube
%global ns_project   RtfHtmlPhp

Name:           php-%{pk_vendor}-%{pk_name}
Version:        2.1
Release:        1%{?dist}
Summary:        RTF to HTML converter

License:        GPLv2
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{name}-%{version}-%{gh_short}.tgz
# Create git snapshot as tests are excluded from official tarball
Source1:        makesrc.sh

BuildArch:      noarch

BuildRequires:  php(language) >= 5.4
BuildRequires:  php-iconv
BuildRequires:  php-mbstring
BuildRequires:  php-pcre
%if %{with tests}
# From composer.json, "require-dev": {
#    "phpunit/phpunit": "^4.8.36 || ^5.7.21 || ^6 || ^7"
BuildRequires:  phpunit9
%global phpunit %{_bindir}/phpunit9
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#    "php": ">=5.4",
#    "ext-iconv": "*",
#    "ext-mbstring": "*"
Requires:       php(language) >= 5.4
Requires:       php-iconv
Requires:       php-mbstring
# From phpcompatifo report for 2.1
Requires:       php-pcre

# Autoloader
Requires:       php-composer(fedora/autoloader)

Provides:       php-composer(%{pk_vendor}/%{pk_name}) = %{version}


%description
An RTF to HTML converter in PHP.

Autoloader: %{_datadir}/php/%{ns_vendor}/%{ns_project}/autoload.php


%prep
%setup -q -n %{gh_project}-%{gh_commit}


%build
: Create classmap autoloader
phpab \
  --template fedora \
  --output src/autoload.php \
  src


%install
mkdir -p   %{buildroot}%{_datadir}/php/%{ns_vendor}
cp -pr src %{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}


%check
%if %{with tests}
: Run upstream test suite
ret=0
for cmdarg in "php %{phpunit}" php73 php74 php80 php81; do
  if which $cmdarg; then
   set $cmdarg
   $1 ${2:- %{_bindir}/phpunit9} \
     --no-coverage \
     --do-not-cache-result \
     --bootstrap %{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}/autoload.php \
     --verbose  tests || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif

%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{_datadir}/php/%{ns_vendor}


%changelog
* Tue Oct 19 2021 Remi Collet <remi@remirepo.net> - 2.1-1
- initial package
